==> haskell-butcher-1.3.3.2-501.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-butcher.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 butcher
version:              1.3.3.2
visibility:           public
id:                   butcher-1.3.3.2-CYGFUFA0KoLB3MjbGSCLe5
key:                  butcher-1.3.3.2-CYGFUFA0KoLB3MjbGSCLe5
license:              BSD-3-Clause
copyright:            Copyright (C) 2016-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
stability:            experimental
homepage:             https://github.com/lspitzner/butcher/
synopsis:
    Chops a command or program invocation into digestable pieces.

description:
    See the <https://github.com/lspitzner/butcher/blob/master/README.md README> (it is properly formatted on github).

category:             UI
abi:                  96418035356d4dc3436e28e6ef3e948e
exposed:              True
exposed-modules:
    UI.Butcher.Monadic UI.Butcher.Monadic.BuiltinCommands
    UI.Butcher.Monadic.Command UI.Butcher.Monadic.Flag
    UI.Butcher.Monadic.IO UI.Butcher.Monadic.Interactive
    UI.Butcher.Monadic.Param UI.Butcher.Monadic.Pretty
    UI.Butcher.Monadic.Types

hidden-modules:
    UI.Butcher.Monadic.Internal.Types UI.Butcher.Monadic.Internal.Core

import-dirs:          /usr/lib/ghc-9.6.6/site-local/butcher-1.3.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/butcher-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/butcher-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-butcher
hs-libraries:         HSbutcher-1.3.3.2-CYGFUFA0KoLB3MjbGSCLe5
depends:
    base-4.18.2.1 bifunctors-5.6.2-46LlpbtsnGiKfj3D3n0SSf
    containers-0.6.7 deque-0.4.4.2-DIYwTC10ib023LsaHVSmhq
    extra-1.7.16-3o8MjPiNQTlLg74BSenHLy free-5.2-3fckYVSYEwRA3sQVkSQiQV
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw mtl-2.3.1
    multistate-0.8.0.4-IyHZlkvn74e2kbINZYQq2d pretty-1.1.3.6
    transformers-0.6.1.0 unsafe-0.0-BBDazQPXbQ7ErhLr2KtCI4
    void-0.7.3-DBkW9SEsEoE4KUGbU5pvgO

haddock-interfaces:   /usr/share/doc/haskell-butcher/html/butcher.haddock
haddock-html:         /usr/share/doc/haskell-butcher/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-butcher-1.3.3.2-502-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-butcher.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 butcher
version:              1.3.3.2
visibility:           public
id:                   butcher-1.3.3.2-76zViD52c5zERCBZXPQDEK
key:                  butcher-1.3.3.2-76zViD52c5zERCBZXPQDEK
license:              BSD-3-Clause
copyright:            Copyright (C) 2016-2020 Lennart Spitzner
maintainer:           Lennart Spitzner <hexagoxel@hexagoxel.de>
author:               Lennart Spitzner
stability:            experimental
homepage:             https://github.com/lspitzner/butcher/
synopsis:
    Chops a command or program invocation into digestable pieces.

description:
    See the <https://github.com/lspitzner/butcher/blob/master/README.md README> (it is properly formatted on github).

category:             UI
abi:                  f20d5f9886e48e88b2dec652fe4f0ed6
exposed:              True
exposed-modules:
    UI.Butcher.Monadic UI.Butcher.Monadic.BuiltinCommands
    UI.Butcher.Monadic.Command UI.Butcher.Monadic.Flag
    UI.Butcher.Monadic.IO UI.Butcher.Monadic.Interactive
    UI.Butcher.Monadic.Param UI.Butcher.Monadic.Pretty
    UI.Butcher.Monadic.Types

hidden-modules:
    UI.Butcher.Monadic.Internal.Types UI.Butcher.Monadic.Internal.Core

import-dirs:          /usr/lib/ghc-9.6.6/site-local/butcher-1.3.3.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/butcher-1.3.3.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/butcher-1.3.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-butcher
hs-libraries:         HSbutcher-1.3.3.2-76zViD52c5zERCBZXPQDEK
depends:
    base-4.18.2.1 bifunctors-5.6.2-A3wf66Vnx89CEVmymYgSB
    containers-0.6.7 deque-0.4.4.2-Kea7RzF2A0mJIBYuENsb0X
    extra-1.7.16-IkudFHstV64EKMSGT8IWWb free-5.2-CP2SAI6deNWCXG1eD5QmMc
    microlens-0.4.14.0-IP2Uuhm3qTnDhkfYobH8B3
    microlens-th-0.4.3.17-IPbJLKFzpBF3M0tXA6bBdw mtl-2.3.1
    multistate-0.8.0.4-10wMcogW8pQBfHzRFo2Ing pretty-1.1.3.6
    transformers-0.6.1.0 unsafe-0.0-BBDazQPXbQ7ErhLr2KtCI4
    void-0.7.3-DBkW9SEsEoE4KUGbU5pvgO

haddock-interfaces:   /usr/share/doc/haskell-butcher/html/butcher.haddock
haddock-html:         /usr/share/doc/haskell-butcher/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
